==> tecton-0.0.21-py3-none-any.whl: tecton/feature_services/feature_service.py <==
from typing import Dict
from typing import List
from typing import Optional
from typing import Union

from tecton import LoggingConfig
from tecton.basic_info import prepare_basic_info
from tecton.feature_packages.feature_package import FeaturePackage
from tecton.feature_services.feature_service_args import FeaturesConfig
from tecton.feature_services.feature_service_args import prepare_args
from tecton_proto.args.feature_service_pb2 import FeatureServiceArgs
from tecton_proto.args.repo_metadata_pb2 import SourceInfo
from tecton_proto.common.id_pb2 import Id
from tecton_spark.logger import get_logger
from tecton_spark.pipeline_helper import FeatureDefinition

logger = get_logger("FeatureService")


class FeatureService:
    """
    Declare a FeatureService.

    In Tecton, a Feature Service exposes an API for accessing a set of FeaturePackages.
    FeatureServices are implemented using the ``FeatureService`` class.

    Once deployed in production, each model has one associated Feature Service that
    serves the model its features. A Feature Service contains a list of the Feature
    Packages associated with a model. It also includes user-provided metadata such as
    name, description, and owner that Tecton uses to organize feature data.
    """

    _args: FeatureServiceArgs
    _source_info: SourceInfo

    def __init__(
        self,
        *,
        name: str,
        description: str = "",
        family: str = "",
        tags: Dict[str, str] = None,
        owner: str = "",
        online_serving_enabled: bool = True,
        features: List[Union[FeaturesConfig, FeaturePackage, FeatureDefinition]] = None,
        logging: Optional[LoggingConfig] = None,
    ):
        """
        Instantiates a new FeatureService.

        :param name: A unique name for the Feature Service.
        :param features: The list of FeaturePackage or FeaturesConfig that this FeatureService will serve.
        :param online_serving_enabled: (Optional, default True) If True, users can send realtime requests
            to this FeatureService, and only FeaturePackages with online materialization enabled can be added
            to this FeatureService.
        :param description: (Optional) description.
        :param family: (Optional) family.
        :param owner: (Optional) Owner name, used to organize features.
        :param tags: (Optional) Arbitrary key-value pairs of tagging metadata.
        :param logging: (Optional) A configuration for logging feature requests sent to this Feature Service.
        """
        from tecton.cli.common import get_fco_source_info

        basic_info = prepare_basic_info(name=name, description=description, owner=owner, family=family, tags=tags)

        self._source_info = get_fco_source_info()
        self._args = prepare_args(
            basic_info=basic_info,
            online_serving_enabled=online_serving_enabled,
            features=features or [],
            logging=logging,
        )

    def _id(self) -> Id:
        return self._args.feature_service_id

    @property
    def name(self) -> str:
        return self._args.info.name

==> tecton-0.0.25-py3-none-any.whl: tecton/feature_services/feature_service.py <==
from typing import Dict
from typing import List
from typing import Optional
from typing import Union

from tecton import LoggingConfig
from tecton._internals.feature_definition import FeatureDefinition
from tecton.basic_info import prepare_basic_info
from tecton.feature_packages.feature_package import FeaturePackage
from tecton.feature_services.feature_service_args import FeaturesConfig
from tecton.feature_services.feature_service_args import prepare_args
from tecton_proto.args.feature_service_pb2 import FeatureServiceArgs
from tecton_proto.args.repo_metadata_pb2 import SourceInfo
from tecton_proto.common.id_pb2 import Id
from tecton_spark.logger import get_logger

logger = get_logger("FeatureService")


class FeatureService:
    """
    Declare a FeatureService.

    In Tecton, a Feature Service exposes an API for accessing a set of FeaturePackages.
    FeatureServices are implemented using the ``FeatureService`` class.

    Once deployed in production, each model has one associated Feature Service that
    serves the model its features. A Feature Service contains a list of the Feature
    Packages associated with a model. It also includes user-provided metadata such as
    name, description, and owner that Tecton uses to organize feature data.
    """

    _args: FeatureServiceArgs
    _source_info: SourceInfo

    def __init__(
        self,
        *,
        name: str,
        description: str = "",
        family: str = "",
        tags: Dict[str, str] = None,
        owner: str = "",
        online_serving_enabled: bool = True,
        features: List[Union[FeaturesConfig, FeaturePackage, FeatureDefinition]] = None,
        logging: Optional[LoggingConfig] = None,
    ):
        """
        Instantiates a new FeatureService.

        :param name: A unique name for the Feature Service.
        :param features: The list of FeaturePackage or FeaturesConfig that this FeatureService will serve.
        :param online_serving_enabled: (Optional, default True) If True, users can send realtime requests
            to this FeatureService, and only FeaturePackages with online materialization enabled can be added
            to this FeatureService.
        :param description: (Optional) description.
        :param family: (Optional) family.
        :param owner: (Optional) Owner name, used to organize features.
        :param tags: (Optional) Arbitrary key-value pairs of tagging metadata.
        :param logging: (Optional) A configuration for logging feature requests sent to this Feature Service.
        """
        from tecton.cli.common import get_fco_source_info

        basic_info = prepare_basic_info(name=name, description=description, owner=owner, family=family, tags=tags)

        self._source_info = get_fco_source_info()
        self._args = prepare_args(
            basic_info=basic_info,
            online_serving_enabled=online_serving_enabled,
            features=features or [],
            logging=logging,
        )

    def _id(self) -> Id:
        return self._args.feature_service_id

    @property
    def name(self) -> str:
        return self._args.info.name
